Module codegen

Module codegen 

Rust code generation from validated definitions and decision trees.

Generates clean, idiomatic Rust code with an impl block containing a decode() function and an enum representing all instruction variants with their fields.

Functions

generate_code
Generate Rust source code from a validated definition and dispatch tree.
to_pascal_case
Convert a DSL instruction name to PascalCase.