pub fn generate_binja_code(
def: &ValidatedDef,
tree: &DecodeNode,
opts: &BinjaOptions,
) -> StringExpand description
Generate a complete Binary Ninja Architecture plugin as a Python string.
pub fn generate_binja_code(
def: &ValidatedDef,
tree: &DecodeNode,
opts: &BinjaOptions,
) -> StringGenerate a complete Binary Ninja Architecture plugin as a Python string.