Rust code generation from validated definitions and decision trees.
Generates clean, idiomatic Rust code with an impl block containing a decode() function
and an enum representing all instruction variants with their fields.
Functions
- generate_
code - Generate Rust source code from a validated definition and dispatch tree.
- to_
pascal_ case - Convert a DSL instruction name to PascalCase.